@@ -31,6 +31,7 @@ const Gio = imports.gi.Gio;
 const Goa = imports.gi.Goa;
 const Gtk = imports.gi.Gtk;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Tracker = imports.gi.Tracker;
 const TrackerControl = imports.gi.TrackerControl;
 
@@ -110,14 +111,17 @@ const Application = new Lang.Class({
         this.isBooks = isBooks;
 
         let appid;
-        if (!this.isBooks) {
-            GLib.set_application_name(_("Documents"));
-            appid = 'org.gnome.Documents';
-        } else {
+        if (this.isBooks) {
             GLib.set_application_name(_("Books"));
             appid = 'org.gnome.Books';
+        } else {
+            GLib.set_application_name(_("Documents"));
+            appid = 'org.gnome.Documents';
         }
 
+        // needed by data/ui/view-menu.ui
+        GObject.type_ensure(Gio.ThemedIcon);
+
         this.parent({ application_id: appid,
                       inactivity_timeout: 12000 });
 
@@ -201,6 +205,15 @@ const Application = new Lang.Class({
         gtkSettings.gtk_application_prefer_dark_theme = state.get_boolean();
     },
 
+    _sortByCreateHook: function(action) {
+        settings.connect('changed::sort-by', Lang.bind(this,
+            function() {
+                let state = settings.get_value('sort-by');
+                if (state.get_string()[0] != action.state.get_string()[0])
+                    action.state = state;
+            }));
+    },
+
     _onActionQuit: function() {
         this._mainWindow.destroy();
     },
@@ -233,6 +246,11 @@ const Application = new Lang.Class({
             settings.set_value('view-as', parameter);
     },
 
+    _onActionSortBy: function(action, parameter) {
+        if (parameter.get_string()[0] != action.state.get_string()[0])
+            settings.set_value('sort-by', parameter);
+    },
+
     _onActionOpenCurrent: function() {
         let doc = documentManager.getActiveItem();
         if (doc)
@@ -283,9 +301,6 @@ const Application = new Lang.Class({
                 if (actionEntry.callback)
                     action.connect('activate', Lang.bind(this, actionEntry.callback));
 
-                if (actionEntry.accel)
-                    this.add_accelerator(actionEntry.accel, 'app.' + actionEntry.name, null);
-
                 if (actionEntry.accels)
                     this.set_accels_for_action('app.' + actionEntry.name, actionEntry.accels);
 
@@ -477,10 +492,10 @@ const Application = new Lang.Class({
         EvDoc.init();
 
         application = this;
-        if (!application.isBooks)
-            settings = new Gio.Settings({ schema_id: 'org.gnome.documents' });
-        else
+        if (application.isBooks)
             settings = new Gio.Settings({ schema_id: 'org.gnome.books' });
+        else
+            settings = new Gio.Settings({ schema_id: 'org.gnome.documents' });
 
         let gtkSettings = Gtk.Settings.get_default();
         gtkSettings.connect('notify::gtk-theme-name', Lang.bind(this, this._themeChanged));
@@ -522,16 +537,16 @@ const Application = new Lang.Class({
         this._actionEntries = [
             { name: 'quit',
               callback: this._onActionQuit,
-              accel: '<Primary>q' },
+              accels: ['<Primary>q'] },
             { name: 'about',
               callback: this._onActionAbout },
             { name: 'help',
               callback: this._onActionHelp,
-              accel: 'F1' },
+              accels: ['F1'] },
             { name: 'fullscreen',
               callback: this._onActionFullscreen,
               create_hook: this._fullscreenCreateHook,
-              accel: 'F11',
+              accels: ['F11'],
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'night-mode',
               callback: this._onActionNightMode,
@@ -540,7 +555,7 @@ const Application = new Lang.Class({
             { name: 'gear-menu',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
-              accel: 'F10' },
+              accels: ['F10'] },
             { name: 'view-as',
               callback: this._onActionViewAs,
               create_hook: this._viewAsCreateHook,
@@ -549,6 +564,14 @@ const Application = new Lang.Class({
               window_modes: [WindowMode.WindowMode.COLLECTIONS,
                              WindowMode.WindowMode.DOCUMENTS,
                              WindowMode.WindowMode.SEARCH] },
+            { name: 'sort-by',
+              callback: this._onActionSortBy,
+              create_hook: this._sortByCreateHook,
+              parameter_type: 's',
+              state: settings.get_value('sort-by'),
+              window_modes: [WindowMode.WindowMode.COLLECTIONS,
+                             WindowMode.WindowMode.DOCUMENTS,
+                             WindowMode.WindowMode.SEARCH] },
             { name: 'open-current',
               callback: this._onActionOpenCurrent,
               window_mode: WindowMode.WindowMode.PREVIEW },
@@ -559,26 +582,26 @@ const Application = new Lang.Class({
               window_mode: WindowMode.WindowMode.PREVIEW,
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
-              accel: 'F5' },
-            { name: 'print-current', accel: '<Primary>p',
+              accels: ['F5'] },
+            { name: 'print-current', accels: ['<Primary>p'],
               callback: this._onActionPrintCurrent },
             { name: 'search',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
-              accel: '<Primary>f' },
-            { name: 'find-next', accel: '<Primary>g',
+              accels: ['<Primary>f'] },
+            { name: 'find-next', accels: ['<Primary>g'],
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'find-prev', accel: '<Shift><Primary>g',
+            { name: 'find-prev', accels: ['<Shift><Primary>g'],
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'zoom-in', accels: ['<Primary>plus', '<Primary>equal'],
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'zoom-out', accel: '<Primary>minus',
+            { name: 'zoom-out', accels: ['<Primary>minus'],
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'rotate-left', accel: '<Primary>Left',
+            { name: 'rotate-left', accels: ['<Primary>Left'],
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'rotate-right', accel: '<Primary>Right',
+            { name: 'rotate-right', accels: ['<Primary>Right'],
               window_mode: WindowMode.WindowMode.PREVIEW },
-            { name: 'select-all', accel: '<Primary>a',
+            { name: 'select-all', accels: ['<Primary>a'],
               window_modes: [WindowMode.WindowMode.COLLECTIONS,
                              WindowMode.WindowMode.DOCUMENTS,
                              WindowMode.WindowMode.SEARCH] },
@@ -592,13 +615,13 @@ const Application = new Lang.Class({
             { name: 'bookmark-page',
               callback: this._onActionToggle,
               state: GLib.Variant.new('b', false),
-              accel: '<Primary>d',
+              accels: ['<Primary>d'],
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'places',
-              accel: '<Primary>b',
+              accels: ['<Primary>b'],
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'copy',
-              accel: '<Primary>c',
+              accels: ['<Primary>c'],
               window_mode: WindowMode.WindowMode.PREVIEW },
             { name: 'search-source',
               parameter_type: 's',
