@@ -331,8 +331,7 @@ const DocCommon = new Lang.Class({
         let iconInfo =
             Gtk.IconTheme.get_default().lookup_by_gicon_for_scale(icon, Utils.getIconSize(),
                                                                   Application.application.getScaleFactor(),
-                                                                  Gtk.IconLookupFlags.FORCE_SIZE |
-                                                                  Gtk.IconLookupFlags.GENERIC_FALLBACK);
+                                                                  Gtk.IconLookupFlags.FORCE_SIZE);
 
         let pixbuf = null;
         if (iconInfo != null) {
@@ -682,25 +681,13 @@ const LocalDocument = new Lang.Class({
         this.sourceName = _("Local");
 
         if (this.mimeType) {
-            let defaultApp = Gio.app_info_get_default_for_type(this.mimeType, true);
-            let recommendedApp = null;
-
             let apps = Gio.app_info_get_recommended_for_type (this.mimeType);
             for (let i = 0; i < apps.length; i++) {
                 if (apps[i].supports_uris ()) {
-                    if (defaultApp && apps[i].equal (defaultApp)) {
-                        // Found the recommended app that's also the default
-                        recommendedApp = apps[i];
-                        break;
-                    }
-                    // Set the first recommendedApp as the default if
-                    // they don't match
-                    if (!recommendedApp)
-                        recommendedApp = apps[i];
+                    this.defaultApp = apps[i];
+                    break;
                 }
             }
-
-            this.defaultApp = recommendedApp;
         }
 
         if (this.defaultApp)
