@@ -198,7 +198,13 @@ const SearchTypeManager = new Lang.Class({
 
         this.addItem(new SearchType({ id: SearchTypeStock.ALL,
                                       name: _("All") }));
-        if (!Application.application.isBooks) {
+        if (Application.application.isBooks) {
+            this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
+                                          name: _("Collections"),
+                                          filter: 'fn:starts-with(nao:identifier(?urn), \"gb:collection\")',
+                                          where: '?urn rdf:type nfo:DataContainer .' }));
+            //FIXME we need to remove all the non-Comics PDFs here
+        } else {
             this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
                                           name: _("Collections"),
                                           filter: 'fn:starts-with(nao:identifier(?urn), \"gd:collection\")',
@@ -207,15 +213,18 @@ const SearchTypeManager = new Lang.Class({
                                           name: _("PDF Documents"),
                                           filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")',
                                           where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
-        } else {
-            this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
-                                          name: _("Collections"),
-                                          filter: 'fn:starts-with(nao:identifier(?urn), \"gb:collection\")',
-                                          where: '?urn rdf:type nfo:DataContainer .' }));
-            //FIXME we need to remove all the non-Comics PDFs here
         }
 
-        if (!Application.application.isBooks) {
+        if (Application.application.isBooks) {
+          this.addItem(new SearchType({ id: SearchTypeStock.EBOOKS,
+                                        name: _("e-Books"),
+                                        filter: '(nie:mimeType(?urn) IN (\"application/epub+zip\", \"application/x-mobipocket-ebook\", \"application/x-fictionbook+xml\", \"application/x-zip-compressed-fb2\", \"image/vnd.djvu+multipage\"))',
+                                        where: '?urn rdf:type nfo:EBook .' }));
+          this.addItem(new SearchType({ id: SearchTypeStock.COMICS,
+                                        name: _("Comics"),
+                                        filter: '(nie:mimeType(?urn) IN (\"application/x-cbr\", \"application/x-cbz\", \"application/x-cbt\", \"application/x-cb7\"))',
+                                        where: '?urn rdf:type nfo:EBook .' }));
+        } else {
             this.addItem(new SearchType({ id: SearchTypeStock.PRESENTATIONS,
                                           name: _("Presentations"),
                                           where: '?urn rdf:type nfo:Presentation .' }));
@@ -226,15 +235,6 @@ const SearchTypeManager = new Lang.Class({
                                           name: _("Text Documents"),
                                           filter: 'NOT EXISTS { ?urn a nfo:EBook }',
                                           where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
-        } else {
-          this.addItem(new SearchType({ id: SearchTypeStock.EBOOKS,
-                                        name: _("e-Books"),
-                                        filter: '(nie:mimeType(?urn) IN (\"application/epub+zip\", \"application/x-mobipocket-ebook\", \"application/x-fictionbook+xml\", \"application/x-zip-compressed-fb2\"))',
-                                        where: '?urn rdf:type nfo:EBook .' }));
-          this.addItem(new SearchType({ id: SearchTypeStock.COMICS,
-                                        name: _("Comics"),
-                                        filter: '(nie:mimeType(?urn) IN (\"application/x-cbr\", \"application/x-cbz\", \"application/x-cbt\", \"application/x-cb7\"))',
-                                        where: '?urn rdf:type nfo:EBook .' }));
         }
 
 
@@ -253,14 +253,14 @@ const SearchTypeManager = new Lang.Class({
     getDocumentTypes: function() {
         let types = [];
 
-        if (!Application.application.isBooks) {
+        if (Application.application.isBooks) {
+            types.push(this.getItemById(SearchTypeStock.EBOOKS));
+            types.push(this.getItemById(SearchTypeStock.COMICS));
+        } else {
             types.push(this.getItemById(SearchTypeStock.PDF));
             types.push(this.getItemById(SearchTypeStock.PRESENTATIONS));
             types.push(this.getItemById(SearchTypeStock.SPREADSHEETS));
             types.push(this.getItemById(SearchTypeStock.TEXTDOCS));
-        } else {
-            types.push(this.getItemById(SearchTypeStock.EBOOKS));
-            types.push(this.getItemById(SearchTypeStock.COMICS));
         }
 
         return types;
@@ -459,10 +459,11 @@ const Source = new Lang.Class({
                 filters.push('(fn:contains (nie:url(?urn), "%s"))'.format(location.get_uri()));
             }));
 
-        if (!Application.application.isBooks)
-            filters.push('(fn:starts-with (nao:identifier(?urn), "gd:collection:local:"))');
-        else
+        if (Application.application.isBooks)
             filters.push('(fn:starts-with (nao:identifier(?urn), "gb:collection:local:"))');
+        else
+            filters.push('(fn:starts-with (nao:identifier(?urn), "gd:collection:local:"))');
+
         return '(' + filters.join(' || ') + ')';
     },
 
