@@ -104,7 +104,10 @@ const Searchbar = new Lang.Class({
             return true;
         }
 
-        return this.handle_event(event);
+        let retval = this.handle_event(event);
+        if (retval == Gdk.EVENT_STOP)
+            this._searchEntry.grab_focus();
+        return retval;
     },
 
     reveal: function() {
@@ -138,7 +141,7 @@ const Dropdown = new Lang.Class({
 
              // HACK: see https://bugzilla.gnome.org/show_bug.cgi?id=733977
              let popover = new Gtk.Popover();
-             popover.bind_model(model.model, 'app');
+             popover.bind_model(model, 'app');
              let w = popover.get_child();
              w.reparent(grid);
              w.valign = Gtk.Align.START;
