@@ -81,8 +81,6 @@ const ViewModel = new Lang.Class({
               GObject.TYPE_LONG,
               GObject.TYPE_BOOLEAN,
               GObject.TYPE_UINT ]);
-        this.set_sort_column_id(Gd.MainColumns.MTIME,
-                                Gtk.SortType.DESCENDING);
 
         this._infoUpdatedIds = {};
         this._resetCountId = 0;
@@ -333,8 +331,8 @@ const ViewContainer = new Lang.Class({
         this.parent({ homogeneous: true,
                       transition_type: Gtk.StackTransitionType.CROSSFADE });
 
-        let grid = new Gtk.Grid({ orientation: Gtk.Orientation.VERTICAL });
-        this.add_named(grid, 'view');
+        this.view = new Gd.MainView({ shadow_type: Gtk.ShadowType.NONE });
+        this.add_named(this.view, 'view');
 
         this._noResults = new EmptyResultsBox();
         this.add_named(this._noResults, 'no-results');
@@ -342,9 +340,6 @@ const ViewContainer = new Lang.Class({
         this._errorBox = new ErrorBox.ErrorBox();
         this.add_named(this._errorBox, 'error');
 
-        this.view = new Gd.MainView({ shadow_type: Gtk.ShadowType.NONE });
-        grid.add(this.view);
-
         this.show_all();
         this.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
 
@@ -360,6 +355,10 @@ const ViewContainer = new Lang.Class({
             Lang.bind(this, this._updateTypeForSettings));
         this._updateTypeForSettings();
 
+        this._sortSettingsId = Application.application.connect('action-state-changed::sort-by',
+            Lang.bind(this, this._updateSortForSettings));
+        this._updateSortForSettings();
+
         // setup selection controller => view
         Application.selectionController.connect('selection-mode-changed',
             Lang.bind(this, this._onSelectionModeChanged));
@@ -418,6 +417,29 @@ const ViewContainer = new Lang.Class({
             this._addListRenderers();
     },
 
+    _updateSortForSettings: function() {
+        let sortBy = Application.settings.get_enum('sort-by');
+        let sortType;
+
+        switch (sortBy) {
+        case Gd.MainColumns.PRIMARY_TEXT:
+            sortType = Gtk.SortType.ASCENDING;
+            break;
+        case Gd.MainColumns.SECONDARY_TEXT:
+            sortType = Gtk.SortType.ASCENDING;
+            break;
+        case Gd.MainColumns.MTIME:
+            sortType = Gtk.SortType.DESCENDING;
+            break;
+        default:
+            sortBy = Gd.MainColumns.MTIME;
+            sortType = Gtk.SortType.DESCENDING;
+            break;
+        }
+
+        this._model.set_sort_column_id(sortBy, sortType);
+    },
+
     activateResult: function() {
         let doc = this._getFirstDocument();
         if (doc)
